/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is ForumZilla 0.1.1.
 *
 * The Initial Developer of the Original Code is Zapogee, Inc.
 * Portions created by Zapogee, Inc. are Copyright (C) 2001
 * Zapogee, Inc.  All Rights Reserved.
 *
 * Contributor(s):
 *   Myk Melez, <myk@melez.com>, original author
 */

// Whether or not to dump debugging messages to the console.
const FZ_DEBUG = true;
var debug;
if (FZ_DEBUG)
  debug = function(msg) { dump('FZ ' + new Date().toLocaleTimeString() + ': ' + msg + '\n'); }
else
  debug = function() {}

var rdf =
  Components
    .classes["@mozilla.org/rdf/rdf-service;1"]
      .getService(Components.interfaces.nsIRDFService);

var rdfcontainer =
  Components
    .classes["@mozilla.org/rdf/container-utils;1"]
      .getService(Components.interfaces.nsIRDFContainerUtils);

var rdfparser =
  Components
    .classes["@mozilla.org/rdf/xml-parser;1"]
      .createInstance(Components.interfaces.nsIRDFXMLParser);

// The feed component uses this to serialize content in Atom feeds.
var serializer =
  Components
    .classes["@mozilla.org/xmlextras/xmlserializer;1"]
      .getService(Components.interfaces.nsIDOMSerializer);

var copyService =
    Components.classes["@mozilla.org/messenger/messagecopyservice;1"]
        .getService(Components.interfaces.nsIMsgCopyService);

// Get the app directory service so we can look up the user's profile dir.
var appDirectoryService =
  Components
    .classes["@mozilla.org/file/directory_service;1"]
      .getService(Components.interfaces.nsIProperties);

const RDF_TYPE = rdf.GetResource("http://www.w3.org/1999/02/22-rdf-syntax-ns#type");

const RSS_NS = "http://purl.org/rss/1.0/";
const RSS_CHANNEL = rdf.GetResource(RSS_NS + "channel");
const RSS_TITLE = rdf.GetResource(RSS_NS + "title");
const RSS_DESCRIPTION = rdf.GetResource(RSS_NS + "description");
const RSS_ITEMS = rdf.GetResource(RSS_NS + "items");
const RSS_ITEM = rdf.GetResource(RSS_NS + "item");
const RSS_LINK = rdf.GetResource(RSS_NS + "link");

const RSS_CONTENT_NS = "http://purl.org/rss/1.0/modules/content/";
const RSS_CONTENT_ENCODED = rdf.GetResource(RSS_CONTENT_NS + "encoded");

const DC_NS = "http://purl.org/dc/elements/1.1/";
const DC_CREATOR = rdf.GetResource(DC_NS + "creator");
const DC_SUBJECT = rdf.GetResource(DC_NS + "subject");
const DC_DATE = rdf.GetResource(DC_NS + "date");
const DC_TITLE = rdf.GetResource(DC_NS + "title");
const DC_IDENTIFIER = rdf.GetResource(DC_NS + "identifier");

const FZ_NS = "urn:forumzilla:";
const FZ_FEED = rdf.GetResource(FZ_NS + "feed");
const FZ_URL = rdf.GetResource(FZ_NS + "url");
const FZ_QUICKMODE = rdf.GetResource(FZ_NS + "quickMode");
const FZ_FOLDER = rdf.GetResource(FZ_NS + "folder");
const FZ_STORED = rdf.GetResource(FZ_NS + "stored");
const FZ_STORING = rdf.GetResource(FZ_NS + "storing");
const FZ_VALID = rdf.GetResource(FZ_NS + "valid");
const FZ_INVALIDATED = rdf.GetResource(FZ_NS + "invalidated");
const FZ_INTERVAL = rdf.GetResource(FZ_NS + "interval");
const FZ_LASTPOLLED = rdf.GetResource(FZ_NS + "lastPolled");
const FZ_ENABLED = rdf.GetResource(FZ_NS + "enabled");

const FZ_ROOT = rdf.GetResource(FZ_NS + "root");
const FZ_FEEDS = rdf.GetResource(FZ_NS + "feeds");

const RDF_LITERAL_TRUE = rdf.GetLiteral("true");
const RDF_LITERAL_FALSE = rdf.GetLiteral("false");

const DEFAULT_POLLING_INTERVAL = 30;

const FOLDER_STORAGE_MODE = 0;
const SUBFOLDERS_STORAGE_MODE = 1;
const DEFAULT_STORAGE_MODE = FOLDER_STORAGE_MODE;

const DEFAULT_STORAGE_FOLDER = "mailbox://nobody@Local%20Folders/Feeds";

function removeAssertions(ds, resource) {
    var properties = ds.ArcLabelsOut(resource);
    var property;
    while (properties.hasMoreElements()) {
        property = properties.getNext();
        var values = ds.GetTargets(resource, property, true);
        var value;
        while (values.hasMoreElements()) {
            value = values.getNext();
            ds.Unassert(resource, property, value, true);
        }
    }
}

var gMsgWindow;
function GetMsgWindow() {
    if (!gMsgWindow) {
        gMsgWindow =
          Components
            .classes["@mozilla.org/messenger/msgwindow;1"]
              .createInstance(Components.interfaces.nsIMsgWindow);
        gMsgWindow.SetDOMWindow(window); 
    }
    return gMsgWindow;
}

function SetBusyCursor(window, enable) {
    if (enable)
        window.setCursor("wait");
    else
        window.setCursor("auto");
}
